@@ -1,4 +1,5 @@
 import base64
+import json
 import time
 from io import BytesIO
 
@@ -61,6 +62,13 @@ class XKSession(AuthSession):
         return login_resp.json()['data']['token']
 
     def is_loggedin(self):
-        return self.get(f'{self.BASE}/student/{self.username}.do', params={
-            'timestamp': int(time.time() * 1000),
-        }).json()['code'] == 200
+        try:
+            info = self.get(f'{self.BASE}/student/{self.username}.do', params={
+                'timestamp': int(time.time() * 1000),
+            }).json()
+        except json.JSONDecodeError:
+            return False
+        if info['code'] == '1':
+            self.info = info['data']
+            return True
+        return False
